Learn R Programming

stppSim (version 1.3.4)

camden_crimes: Records of crimes of Camden Borough of London, UK, 2021 (Source: https://data.police.uk/data/)

Description

Data comprising 'Theft' and 'Criminal Damage' records of Camden Borough of London, UK for the year 2021 (Source: https://data.police.uk/). Note: Police.uk data is aggregated at monthly scale (yyyy-mm). But, the data provided here has been disaggregated to daily scale by adding fake 'daily' stamps (to give yyyy-mm-dd). So, caution should be taken when interpreting the results based on full date.

Usage

camden_crimes

Arguments

Format

A matrix containing four variables

  • x: x coordinate

  • y: y coordinate

  • date: date of occurence

  • type: types of crime